#!/bin/sh
#
# Name: acsd
# Date: 2010-04-12 12:00
# Copyright: (C) 2010 Iskratel
# Author:	 Cvetka Milinovic <milinovic@iskratel.si>
# This software licensed to Iskratel Ltd.
#
#
### BEGIN INIT INFO
# Required-Start:
# Required-Stop:
# Should-Start:
# Should-Stop:
# Default-Start: 2 3 4 5
# Default-Stop: 0 1 6
# Short-Description: start/stop ACS client.
# Description: Start and stop ACS Client.
# chkconfig: 2345 99 10
### END INIT INFO

# Init script information
INIT_NAME=acs.sh
DESC="ACS client"
DAEMON_NAME="acs"
PACKAGE_PATH="/opt/iskratel/"
WORKING_DIR=$PACKAGE_PATH"bin"
APPLICATION=$WORKING_DIR/$DAEMON_NAME
ACS_CONFIG=${PACKAGE_PATH}/etc/acs.cfg
PRODUCT_CONFIG="/etc/sysconfig/info-product"

SIGUSR1=10
SIGUSR3=64
SIGTERM=15

# Following arguments are possible: debug|consolelog|nosyslog
ARGUMENTS=""

PID_FILE="/var/run/$DAEMON_NAME.pid"

STOP_WAITING_LIMIT=15  # in seconds

# Test standalone flag provided by dhcp
# Test program ncfmCli returns:
#  0 - no standalone configuration
#  1 - standalone configuration
TEST_STANDALONE_PROG=/opt/iskratel/sbin/ncfmCli
TEST_STANDALONE_ARG="get std-flag"
NUM_TRIES=1
OS_BOOT_INFO_FILE=/etc/sysconfig/boot-type-info


start()
{
	# Read import variables
	if [ -e ${OS_BOOT_INFO_FILE} ]
	then
     	   . ${OS_BOOT_INFO_FILE}
	fi

	if [ -e ${ACS_CONFIG} ]
	then
		. ${ACS_CONFIG}
	else
		echo "File ${ACS_CONFIG} not exists, ACS client may not work correct!!"
	fi
	if [ -e ${PRODUCT_CONFIG} ]
	then
		. ${PRODUCT_CONFIG}
	fi
	local RET ERROR=
	PID=`pidof $APPLICATION`
        if [ -e ${TEST_STANDALONE_PROG} ]
        then
                        standalone_config=`${TEST_STANDALONE_PROG} ${TEST_STANDALONE_ARG}`
                else
                        standalone_config=1
        fi
	echo "Starting $DESC: $DAEMON_NAME... "
	[ -e /etc/default/sys_profile ] && . /etc/default/sys_profile  # This line should be added in start script
        while test ${NUM_TRIES} -gt 0
        do
	        if [ "$PID" == "" -a $standalone_config -eq 1 ]
	        then
		        $APPLICATION $ARGUMENTS &
		        echo -n $!  > $PID_FILE
                        sleep 5
	                PID=`pidof $APPLICATION`
	                if [ "$PID" == "" ]
	                then
		                rm $PID_FILE
                                NUM_TRIES=`expr ${NUM_TRIES} - 1`
                                if [ ${NUM_TRIES} -gt 0 ]
                                then
                                        echo "Can not start $DESC trying left ${NUM_TRIES} !!!!"
                                fi
	                else
		                echo "done ..."
                                NUM_TRIES=0
	                fi
	        else
                        NUM_TRIES=0
                        if [ $standalone_config -eq 0 ]
                        then
                                echo "Starting $DESC not allowed in one IP configuration!"
                        else
                                echo "$DESC already started!" 
                        fi
		        return 0
	        fi
        done
	return 0
}

stop () {
	local RET ERROR=
	local cnt=0
	local sleepPeriod=2
	local max=`expr $STOP_WAITING_LIMIT / $sleepPeriod`

	PID=`pidof $APPLICATION`
	if [ "$PID" == "" ]
	then
		echo "$DESC not started"
		return 0
	fi

	echo "Stopping $DESC: $DAEMON_NAME... "
	kill "-$SIGTERM" "$PID"
	RET=$?
	if [ $RET -eq 0 ]; then
		echo " done. "
	else
		echo "failed ($RET: Unable to stop $DAEMON_NAME). "
	fi
	return 0
}

restart() {
	local RET

	echo "Restarting $DESC..."
	stop
	start
	RET=$?

	return $RET
}

tryrestart() {
	local RET

	PID=`pidof $APPLICATION`
	RET=$?
	if [ "$RET" == "" ]; then
		restart
		RET=$?
	else
		RET=7
	fi

	return $RET
}

#
# if the service does not support reload return code 3 should
# be the result...
#
reload() {
	local RET
	PID=`pidof $APPLICATION`
	if [ "$PID" == "" ]
	then
		echo "$DESC not started"
		return 3
	fi
	echo "Reloading $DESC: $DAEMON_NAME... "
	kill "-$SIGUSR1" "$PID"
	RET=$?
	return $RET
}

forcereload() {
	local RET

	reload
	RET=$?
	if [ $RET -ne 0 ]; then
		restart
		RET=$?
	fi

	return $RET
}

status() {
	PID=`pidof $APPLICATION`
	if [ "$PID" == "" ]
	then
		echo "$DESC not running! "
	else
		echo "$DESC is running (PID = $PID)!"
	fi
	return 0
}

#
# In case when Http server present then Http ping over port 80 for ACS must be impelemented by calling this script
#
ping() {
	local RET
	PID=`pidof $APPLICATION`
	if [ "$PID" == "" ]
	then
		echo "$DESC not started, Http ping not possible"
		return 3
	fi
	echo "Http request for $DESC: $DAEMON_NAME... "
	kill "-$SIGUSR3" "$PID"
	RET=$?
	return $RET
}

#
# Everything after this should be the same for all init scripts
#
# See the policy manual for information on actions and return codes.
#

parse() {
	case "$1" in
		start)
			start
			return $?
			  ;;
		stop)
			stop
			return $?
			;;
		restart)
			restart
			return $?
			;;
		try-restart)
			tryrestart
			return $?
			;;
		 reload)
			reload
			return $?
			;;
		force-reload)
			forcereload
			return $?
			;;
		status)
			status
			return $?
			;;
 		http-ping)
			ping
			return $?
			;;
		 *)
			echo "Usage: $INIT_NAME " \
			"{start | stop | restart | try-restart | reload | "\
			"force-reload | status }" >&2
			;;
	esac

	return 1
}

parse $@
